#!/usr/bin/env python
# -*- coding: utf-8 -*-
""" Author: MOBIO
    Date created: 2019/03/01
"""
import configparser
import logging.config

from mobio.libs.Singleton import Singleton
from mobio.sdks.base.configs import ApplicationConfig


@Singleton
class SystemConfig:
    config = configparser.ConfigParser()
    _sections = {}

    def __init__(self):
        self.config.read(ApplicationConfig.CONFIG_FILE_PATH, 'utf-8')

    def get_section_map(self, section):
        if section in self._sections:
            return self._sections[section]

        local_dic = {}
        options = self.config.options(section)
        for option in options:
            try:
                local_dic[option] = self.config.get(section, option)
                if local_dic[option] == -1:
                    print("INFO:MOBIO:SystemConfig.get_section_map():skip: %s" % option)
            except Exception as e:
                print("ERROR:MOBIO::SystemConfig.get_section_map():section: %s" % section)
                print("ERROR:MOBIO::SystemConfig.get_section_map():option: %s" % option)
                print("ERROR:MOBIO::SystemConfig.get_section_map():error: %s" % e)
                local_dic[option] = None
        self._sections[section] = local_dic
        return local_dic



#!/usr/bin/env python
# -*- coding: utf-8 -*-
""" Author: ChungNT
    Company: MobioVN
    Date created: 19/03/2021
"""
import logging
import os
import sys
import traceback

from mobio.libs.Singleton import Singleton
from mobio.sdks.base.common import CONSTANTS
from mobio.sdks.base.common.system_config import SystemConfig
from mobio.sdks.base.configs import LoggingConfig, ApplicationConfig
from logstash_formatter import LogstashFormatterV1


class LOGGING:
    WRITE_TRACEBACK_FOR_ALL_CUSTOMIZE_EXCEPTION = "write_traceback_for_all_customize_exception"
    WRITE_TRACEBACK_FOR_GLOBAL_EXCEPTION = "write_traceback_for_global_exception"
    LOG_FOR_REQUEST_SUCCESS = "log_for_request_success"
    LOG_FOR_ALL_CUSTOMIZE_EXCEPTION = "log_for_all_customize_exception"
    LOG_FOR_GLOBAL_EXCEPTION = "log_for_global_exception"
    FILE_MAX_BYTES = "file_max_bytes"
    FILE_BACKUP_COUNT = "file_backup_count"


@Singleton
class MobioLogging:
    def __init__(self):

        if not LoggingConfig.K8S:
            logging.config.fileConfig(ApplicationConfig.LOG_CONFIG_FILE_PATH, None, disable_existing_loggers=False)

        self.logger = logging.getLogger('MOBIO')
        max_bytes = int(SystemConfig().get_section_map(CONSTANTS.LOGGING_MODE)[CONSTANTS.FILE_MAX_BYTES])
        backup_count = int(SystemConfig().get_section_map(CONSTANTS.LOGGING_MODE)[CONSTANTS.FILE_BACKUP_COUNT])
        if max_bytes > 0:
            try:
                os.makedirs(os.path.dirname(ApplicationConfig.LOG_FILE_PATH), exist_ok=True)
            except Exception as ex:
                print('WARNING:mobio_logging::__init__():make log dir: %s' % ex)
            self.logger.addHandler(logging.handlers.RotatingFileHandler(filename=ApplicationConfig.LOG_FILE_PATH,
                                                                        maxBytes=max_bytes,
                                                                        backupCount=backup_count))

        handler = logging.StreamHandler(stream=sys.stdout)
        handler.setFormatter(LogstashFormatterV1())
        logging.basicConfig(handlers=[handler], level=logging.DEBUG)

    def warning(self, content, log_key=None):
        if isinstance(content, dict) and LoggingConfig.K8S:
            content["log_key"] = log_key
        self.logger.warning(content)

    def debug(self, content, log_key=None):
        if isinstance(content, dict) and LoggingConfig.K8S:
            content["log_key"] = log_key
        traceback.print_last()
        self.logger.debug(content)

    def error(self, content, log_key=None):
        if isinstance(content, dict) and LoggingConfig.K8S:
            content["log_key"] = log_key
        traceback.print_exc()
        self.logger.error(content)

    def info(self, content, log_key=None):
        if isinstance(content, dict) and LoggingConfig.K8S:
            content["log_key"] = log_key
        self.logger.info(content)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


class CONSTANTS:
    SECTION = 'section'
    LOGGING_MODE = 'logging_mode'
    FILE_MAX_BYTES = 'file_max_bytes'
    FILE_BACKUP_COUNT = 'file_backup_count'




#!/usr/bin/env python
# -*- coding: utf-8 -*-
""" Author: ChungNT
    Company: MobioVN
    Date created: 20/04/2021
"""
from flask import Blueprint, jsonify

checking_service_mod = Blueprint('checking_service', __name__)


@checking_service_mod.route('/ping', methods=['GET'])
def ping():
    return jsonify({"code": 200}), 200



#!/usr/bin/python
# -*- coding: utf8 -*-

from mobio.libs.validator import HttpValidator, VALIDATION_RESULT

from src.common import LANG
from src.common.mobio_exception import ParamInvalidError


class BaseController(object):
    PARAM_INVALID_VALUE = 412

    @staticmethod
    def abort_if_validate_error(rules, data):
        valid = HttpValidator(rules)
        val_result = valid.validate_object(data)
        if not val_result[VALIDATION_RESULT.VALID]:
            errors = val_result[VALIDATION_RESULT.ERRORS]
            raise ParamInvalidError(LANG.VALIDATE_ERROR, errors)

    @staticmethod
    def validate_optional_err(rules, data):
        valid = HttpValidator(rules)
        val_result = valid.validate_optional(data)
        if not val_result[VALIDATION_RESULT.VALID]:
            errors = val_result[VALIDATION_RESULT.ERRORS]
            raise ParamInvalidError(LANG.VALIDATE_ERROR, errors)

    @staticmethod
    def abort_if_param_empty_error(param, param_name):
        if param is None or param is '':
            raise ParamInvalidError(LANG.MUST_NOT_EMPTY, param_name)

    def __init__(self):
        pass


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os


class ApplicationConfig:
    BASE_HOST = str(os.environ.get("HOST"))
    APPLICATION_DATA_DIR = os.environ.get('APPLICATION_DATA_DIR')
    APPLICATION_LOGS_DIR = os.environ.get('APPLICATION_LOGS_DIR')
    MOBIO_TOKEN = os.environ.get('YEK_REWOP', '')

    CONFIG_FILE_PATH = ''
    LOG_CONFIG_FILE_PATH = ''
    LOG_FILE_PATH = ''


class LoggingConfig:
    K8S = bool(int(os.environ.get("K8S", '0')))



import os

from setuptools import setup, find_packages

# read the contents of your README file

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='mobio-base-sdk-dev',
      version='1.0.11',
      description='Mobio project SDK',
      url='',
      author='MOBIO',
      author_email='contact@mobio.vn',
      license='MIT',
      package_dir={'': './'},
      packages=find_packages('./'),
      install_requires=['m-singleton',
                        'm-monitor',
                        'm-validator',
                        'Flask>=1.1.2',
                        'configparser==3.5.0',
                        'logstash_formatter==0.5.17'],
      long_description=long_description,
      long_description_content_type='text/markdown',
      python_requires='>=3.7'
      )
